@@ -4,10 +4,13 @@ module Mocha
 
   class ClassMethod
 
+    PrependedModule = Class.new(Module)
+
     attr_reader :stubbee, :method
 
     def initialize(stubbee, method)
-      @stubbee, @original_method = stubbee, nil
+      @stubbee = stubbee
+      @original_method, @original_visibility = nil, nil
       @method = RUBY_VERSION < '1.9' ? method.to_s : method.to_sym
     end
 
@@ -37,15 +40,17 @@ module Mocha
       if method_exists?(method)
         begin
           @original_method = stubbee._method(method)
+          @original_visibility = :public
+          if stubbee.__metaclass__.protected_instance_methods.include?(method)
+            @original_visibility = :protected
+          elsif stubbee.__metaclass__.private_instance_methods.include?(method)
+            @original_visibility = :private
+          end
           if @original_method && @original_method.owner == stubbee.__metaclass__
-            @original_visibility = :public
-            if stubbee.__metaclass__.protected_instance_methods.include?(method)
-              @original_visibility = :protected
-            elsif stubbee.__metaclass__.private_instance_methods.include?(method)
-              @original_visibility = :private
-            end
             stubbee.__metaclass__.send(:remove_method, method)
           end
+
+          include_prepended_module if RUBY_VERSION >= '2.0'
         rescue NameError
           # deal with nasties like ActiveRecord::Associations::AssociationProxy
         end
@@ -53,24 +58,33 @@ module Mocha
     end
 
     def define_new_method
-      stubbee.__metaclass__.class_eval(%{
+      definition_target.class_eval(<<-CODE, __FILE__, __LINE__ + 1)
         def #{method}(*args, &block)
           mocha.method_missing(:#{method}, *args, &block)
         end
-      }, __FILE__, __LINE__)
+      CODE
+      if @original_visibility
+        Module.instance_method(@original_visibility).bind(definition_target).call(method)
+      end
     end
 
     def remove_new_method
-      stubbee.__metaclass__.send(:remove_method, method)
+      definition_target.send(:remove_method, method)
     end
 
     def restore_original_method
       if @original_method && @original_method.owner == stubbee.__metaclass__
-        original_method = @original_method
-        stubbee.__metaclass__.send(:define_method, method) do |*args, &block|
-          original_method.call(*args, &block)
+        if RUBY_VERSION < '1.9'
+          original_method = @original_method
+          stubbee.__metaclass__.send(:define_method, method) do |*args, &block|
+            original_method.call(*args, &block)
+          end
+        else
+          stubbee.__metaclass__.send(:define_method, method, @original_method)
         end
-        stubbee.__metaclass__.send(@original_visibility, method)
+      end
+      if @original_visibility
+        Module.instance_method(@original_visibility).bind(stubbee.__metaclass__).call(method)
       end
     end
 
@@ -91,6 +105,23 @@ module Mocha
       __metaclass__.public_method_defined?(symbol) || __metaclass__.protected_method_defined?(symbol) || __metaclass__.private_method_defined?(symbol)
     end
 
+    private
+
+    def include_prepended_module
+      possible_prepended_modules = stubbee.__metaclass__.ancestors.take_while do |mod|
+        !(Class === mod)
+      end
+
+      if possible_prepended_modules.any?
+        @definition_target = PrependedModule.new
+        stubbee.__metaclass__.__send__ :prepend, @definition_target
+      end
+    end
+
+    def definition_target
+      @definition_target ||= stubbee.__metaclass__
+    end
+
   end
 
 end
