@@ -9,7 +9,7 @@ module Mocha
     end
 
     def match?(actual_method_name)
-      @expected_method_name == actual_method_name
+      @expected_method_name == actual_method_name.to_sym
     end
 
     def mocha_inspect
