@@ -1,7 +1,7 @@
 require File.expand_path('../acceptance_test_helper', __FILE__)
-require 'mocha'
+require 'mocha/setup'
 
-class Bug21563Test < Test::Unit::TestCase
+class Bug21563Test < Mocha::TestCase
 
   include AcceptanceTest
 
