@@ -2,8 +2,8 @@ require File.expand_path('../../test_helper', __FILE__)
 require 'mocha/inspect'
 require 'method_definer'
 
-class ObjectInspectTest < Test::Unit::TestCase
-  
+class ObjectInspectTest < Mocha::TestCase
+
   def test_should_return_default_string_representation_of_object_not_including_instance_variables
     object = Object.new
     class << object
@@ -13,7 +13,7 @@ class ObjectInspectTest < Test::Unit::TestCase
     assert_match Regexp.new("^#<Object:0x[0-9A-Fa-f]{1,8}.*>$"), object.mocha_inspect
     assert_no_match(/instance_variable/, object.mocha_inspect)
   end
-  
+
   def test_should_return_customized_string_representation_of_object
     object = Object.new
     class << object
@@ -21,7 +21,7 @@ class ObjectInspectTest < Test::Unit::TestCase
     end
     assert_equal 'custom_inspect', object.mocha_inspect
   end
-  
+
   def test_should_use_underscored_id_instead_of_object_id_or_id_so_that_they_can_be_stubbed
     calls = []
     object = Object.new
@@ -34,5 +34,5 @@ class ObjectInspectTest < Test::Unit::TestCase
 
     assert_equal [:__id__], calls.uniq
   end
-  
+
 end
