@@ -5,7 +5,7 @@ require 'mocha/parameter_matchers/object'
 require 'mocha/parameter_matchers/equals'
 require 'mocha/inspect'
 
-class HasEntryTest < Test::Unit::TestCase
+class HasEntryTest < Mocha::TestCase
 
   include Mocha::ParameterMatchers
 
@@ -79,6 +79,13 @@ class HasEntryTest < Test::Unit::TestCase
     assert !matcher.matches?([object])
   end
 
+  def test_should_raise_argument_error_if_single_argument_is_not_a_hash
+    e = assert_raises(ArgumentError) do
+      has_entry(Array.new)
+    end
+    assert_equal "Argument is not a Hash.", e.message
+  end
+
   def test_should_raise_argument_error_if_no_entries_are_supplied
     e = assert_raises(ArgumentError) do
       has_entry({})
@@ -93,4 +100,30 @@ class HasEntryTest < Test::Unit::TestCase
     assert_equal "Argument has multiple entries. Use Mocha::ParameterMatchers#has_entries instead.", e.message
   end
 
+  def test_should_raise_argument_error_if_more_than_two_arguments_are_supplied
+    e = assert_raises(ArgumentError) do
+      has_entry(1, 2, 3)
+    end
+    assert_equal "Too many arguments; use either a single argument (must be a Hash) or two arguments (a key and a value).", e.message
+  end
+
+  def test_should_match_array_as_key
+    matcher = has_entry([:key_1, :key_2] => 'value_1')
+    assert matcher.matches?([{[:key_1, :key_2] => 'value_1', :key_3 => 'value_2'}])
+  end
+
+  def test_should_match_array_as_value
+    matcher = has_entry(:key_1 => ['value_1', 'value_2'])
+    assert matcher.matches?([{:key_1 => ['value_1', 'value_2']}])
+  end
+
+  def test_should_match_hash_as_value_and_key
+    matcher = has_entry({{:key_1 => 'value_1', :key_2 => 'value_2'} => {:key_3 => 'value_3', :key_4 => 'value_4'}})
+    assert matcher.matches?([{{:key_1 => 'value_1', :key_2 => 'value_2'} => {:key_3 => 'value_3', :key_4 => 'value_4'}, :key_5 => 'value_5'}])
+  end
+
+  def test_should_match_matcher_as_value_and_key
+    matcher = has_entry({has_entry(:key_1 => 'value_1') => has_entry(:key_3 => 'value_3')})
+    assert matcher.matches?([{{:key_1 => 'value_1', :key_2 => 'value_2'} => {:key_3 => 'value_3', :key_4 => 'value_4'}, :key_5 => 'value_5'}])
+  end
 end
