@@ -1,6 +1,7 @@
 require File.expand_path('../../../test_helper', __FILE__)
 
 require 'mocha/parameter_matchers/responds_with'
+require 'mocha/parameter_matchers/object'
 require 'mocha/inspect'
 
 class RespondsWithTest < Mocha::TestCase
@@ -17,6 +18,12 @@ class RespondsWithTest < Mocha::TestCase
     assert !matcher.matches?(['bar'])
   end
 
+  def test_should_match_parameter_responding_with_nested_responds_with_matcher
+    matcher = responds_with(:foo, responds_with(:bar, 'baz'))
+    object = Class.new { def foo; Class.new { def bar; 'baz'; end }.new; end }.new
+    assert matcher.matches?([object])
+  end
+
   def test_should_describe_matcher
     matcher = responds_with(:foo, :bar)
     assert_equal 'responds_with(:foo, :bar)', matcher.mocha_inspect
